==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Acuèlh del sit', # MODIF
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquel autor',
	'articles_populaires' => 'Los articles mai populars',
	'articles_rubrique' => 'Articles d’aquela rubrica',
	'aucun_article' => 'I a pas cap d’article a aquela adreiça ',
	'aucun_auteur' => 'I a pas cap d’autor a aquela adreiça ',
	'aucun_site' => 'I a pas cap de sit a aquela adreiça ',
	'aucune_breve' => 'I a pas cap de brèva a aquela adreiça ',
	'aucune_rubrique' => 'I a pas cap de rubrica a aquela adreiça ',
	'autres_breves' => 'Autras brèvas',
	'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Adieu-siatz',

	// C
	'commenter_site' => 'Comentar aquel sit',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrièr apondon',
	'dernieres_breves' => 'Darrièras brèvas',
	'derniers_articles' => 'Darrièrs articles',
	'derniers_commentaires' => 'Darrièrs comentaris',
	'derniers_messages_forum' => 'Darrièrs messatges publicats dins los forums',

	// E
	'edition_mode_texte' => 'Edicion en mòde tèxt de',
	'en_reponse' => 'En responsa a:',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// H
	'hierarchie_site' => 'Ierarquia del sit',

	// J
	'jours' => 'jorns',

	// M
	'meme_auteur' => 'Del meteis autor',
	'meme_rubrique' => 'Dins la meteissa rubrica',
	'memes_auteurs' => 'Dels meteisses autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges de forum', # MODIF
	'messages_recents' => 'Los messatges de forums mai recents',
	'mots_clefs' => 'Mots clau',
	'mots_clefs_meme_groupe' => 'Mots clau dins lo meteis grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Las novetats',
	'nouveautes_web' => 'Novetats subre lo web',
	'nouveaux_articles' => 'Articles nòus',
	'nouvelles_breves' => 'Brèvas nòvas',

	// P
	'page_precedente' => 'pagina precedenta',
	'page_suivante' => 'pagina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Podètz participar a la vida d’aquel sit e prepausar los articles vòstres en vos inscriure çai jos. Recebretz còp sec un e-mail que vos indicarà vòstres còdes per accedir a l’espaci privat del sit.',
	'plan_site' => 'Plan del sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Podètz prepausar un sit d’apondre a aquesta rubrica:',

	// R
	'repondre_article' => 'Respondre a aquel article',
	'repondre_breve' => 'Respondre a aquela brèva',
	'resultats_recherche' => 'Resultats de la cèrca',
	'retour_debut_forums' => 'Retorn al començament dels forums',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realizat amb SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'suite' => 'seguida',
	'sur_web' => 'Subre lo web',
	'syndiquer_rubrique' => 'Sindicar aquela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vaicí la letra d’informacion del sit',
	'texte_lettre_information_2' => 'Aquela letra recensa los articles e brèvas publicats dempuèi', # MODIF

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Vejatz en linha',
	'voir_squelette' => 'veire l’esqueleta d’aquela pagina'
);

==> spip_4.4.3+dfsg.orig.tar.xz: ecrire/lang/public_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Acuèlh del sit', # MODIF
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquel autor',
	'articles_populaires' => 'Los articles mai populars',
	'articles_rubrique' => 'Articles d’aquela rubrica',
	'aucun_article' => 'I a pas cap d’article a aquela adreiça ',
	'aucun_auteur' => 'I a pas cap d’autor a aquela adreiça ',
	'aucun_site' => 'I a pas cap de sit a aquela adreiça ',
	'aucune_breve' => 'I a pas cap de brèva a aquela adreiça ',
	'aucune_rubrique' => 'I a pas cap de rubrica a aquela adreiça ',
	'autres_breves' => 'Autras brèvas',
	'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Adieu-siatz',

	// C
	'commenter_site' => 'Comentar aquel sit',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrièr apondon',
	'dernieres_breves' => 'Darrièras brèvas',
	'derniers_articles' => 'Darrièrs articles',
	'derniers_commentaires' => 'Darrièrs comentaris',
	'derniers_messages_forum' => 'Darrièrs messatges publicats dins los forums',

	// E
	'edition_mode_texte' => 'Edicion en mòde tèxt de',
	'en_reponse' => 'En responsa a:',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// H
	'hierarchie_site' => 'Ierarquia del sit',

	// J
	'jours' => 'jorns',

	// M
	'meme_auteur' => 'Del meteis autor',
	'meme_rubrique' => 'Dins la meteissa rubrica',
	'memes_auteurs' => 'Dels meteisses autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges de forum', # MODIF
	'messages_recents' => 'Los messatges de forums mai recents',
	'mots_clefs' => 'Mots clau',
	'mots_clefs_meme_groupe' => 'Mots clau dins lo meteis grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Las novetats',
	'nouveautes_web' => 'Novetats subre lo web',
	'nouveaux_articles' => 'Articles nòus',
	'nouvelles_breves' => 'Brèvas nòvas',

	// P
	'page_precedente' => 'pagina precedenta',
	'page_suivante' => 'pagina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Podètz participar a la vida d’aquel sit e prepausar los articles vòstres en vos inscriure çai jos. Recebretz còp sec un e-mail que vos indicarà vòstres còdes per accedir a l’espaci privat del sit.',
	'plan_site' => 'Plan del sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Podètz prepausar un sit d’apondre a aquesta rubrica:',

	// R
	'repondre_article' => 'Respondre a aquel article',
	'repondre_breve' => 'Respondre a aquela brèva',
	'resultats_recherche' => 'Resultats de la cèrca',
	'retour_debut_forums' => 'Retorn al començament dels forums',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realizat amb SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'suite' => 'seguida',
	'sur_web' => 'Subre lo web',
	'syndiquer_rubrique' => 'Sindicar aquela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vaicí la letra d’informacion del sit',
	'texte_lettre_information_2' => 'Aquela letra recensa los articles e brèvas publicats dempuèi', # MODIF

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Vejatz en linha',
	'voir_squelette' => 'veire l’esqueleta d’aquela pagina',
];
